#
# spec file for package pybliographer
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pybliographer
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  libtool
BuildRequires:  python-bibtex
BuildRequires:  python-devel
BuildRequires:  python-gnome-devel
BuildRequires:  scrollkeeper
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
%if 0%{suse_version} < 1200
BuildRequires:  xz
%endif

Summary:        A Tool for Bibliographic Databases
License:        GPL-2.0+
Group:          Productivity/Publishing/Other
Version:        1.2.17
Release:        1.1
Source:         http://freefr.dl.sourceforge.net/project/pybliographer/Sources%20-%201.2/%{version}/pybliographer-%{version}.tar.gz
Patch0:         pybliographer-1.1.93-destdir.patch
Patch1:         pybliographer-1.2.1-check.patch
# PATCH-FIX-UPSTREAM pybliographer-pot.patch sbrabec@suse.cz -- Fixed pot file generation.
Patch2:         pybliographer-pot.patch
Requires:       python-bibtex >= 1.2.2
Requires:       python-gnome
Requires:       python-gtk >= 2.4.0
Requires:       python-orbit
Requires:       python-xml
PreReq:         filesystem /usr/bin/touch
# Package was renamed in 2000 from pybliog 1.0.5
Provides:       pybliog = 1.0.5
Obsoletes:      pybliog < 1.0.5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://pybliographer.org/
%if %{?suse_version: %{suse_version} > 1110} %{!?suse_version:1}
BuildArch:      noarch
%endif

%description
Pybliographer is a tool for managing bibliographic databases. It
currently supports the following formats:

* BibTeX (quite complete)
* Medline (read-only)
* Ovid files (from ovid.com)
* Refer and EndNote (read only)
* SGML DocBook (write only)

Pybliographer can be used for searching, editing, reformatting, etc. In
fact, it's a simple framework that provides easy to use python classes
and functions, and therefore can be extended to any usage (generating
HTML pages according to bibliographic searches, etc).

In addition to the scripting environment, a graphical GNOME interface
is available. It provides powerful editing capabilities, in addition to
a nice hierarchical search mechanism.

%prep
%setup -q
%patch2
translation-update-upstream
%patch0
%patch1 -p1
%patch2 -p1

%build
libtoolize --force
autoreconf -f -i
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=%{_prefix} --libdir=%{_libdir} --disable-depchecks
make

%install
make DESTDIR=$RPM_BUILD_ROOT install
# install -d $RPM_BUILD_ROOT%{_prefix}/share/gnome/apps/Applications
# install -m644 *.desktop \
#   $RPM_BUILD_ROOT%{_prefix}/share/gnome/apps/Applications
[ -d $RPM_BUILD_ROOT%{_prefix}/share/locale/no ] && {
  install -d $RPM_BUILD_ROOT%{_prefix}/share/locale/nb/LC_MESSAGES
  cp $RPM_BUILD_ROOT%{_prefix}/share/locale/no/LC_MESSAGES/*.mo \
    $RPM_BUILD_ROOT%{_prefix}/share/locale/nb/LC_MESSAGES
  rm -fr $RPM_BUILD_ROOT%{_prefix}/share/locale/no
}

rm -f $RPM_BUILD_ROOT/usr/share/applications/mimeinfo.cache
%suse_update_desktop_file  pybliographic Database
%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{name}.lang
%defattr(-, root, root)
%{_bindir}/*
%{_datadir}/applications/*.desktop
%doc %{_datadir}/gnome/help/pybliographer
%dir %{_datadir}/mime-info
%{_datadir}/mime-info/pybliographic.*
%{_datadir}/pixmaps/pybliographic*
%{_datadir}/pybliographer
%dir %{_datadir}/appdata/
%{_datadir}/appdata/pybliographic.appdata.xml

%changelog
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to 1.2.17:
  * Fixed exit issues in command line
  * Pybliographer now includes and installs an AppData file
  * Saving bibtex entries sorted
  * Minor fixes of translations, installation system and the GUI
  * Added Greek translation of the documentation (Gnome I18n team)
  * Updated translations (Gnome I18n team)
- switch source to tar.gz, to match the published archive
- drop pybliographer-1.2.16-automake113.patch: fixed upstream
- add pybliographic.appdata.xml to package
* Mon Sep  9 2013 jmatejek@suse.com
- update to 1.2.16
  * renamed command-line scripts
  * updated translations
  * switch to xz compression
- updated patches to reflect renamed scripts
* Wed Jul 17 2013 jmatejek@suse.com
- update to 1.2.15
  * converted docs to Mallard format
  * gnome cosmetic fixes
  * DateError bug fixed
  * updated translations
  * requires pygtk >= 2.14.0
- fixed build with automake 1.13 (pybliographer-1.2.15-automake113.patch)
- added requirement for gnome-doc-utils-devel
* Tue Aug 28 2012 idonmez@suse.com
- Don't move sr@Latn to sr@latin anymore.
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Feb 15 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Thu Sep 16 2010 coolo@novell.com
- update to 1.2.13
  * Some minor gtk related fixes
  * Updated translations (Gnome I18n team)
* Wed Sep 23 2009 aj@suse.de
- Cleanup BuildRequires.
- Fix rpmlint warnings:
  * Fix provide/obsolete versioning.
  * Mark doc and lang files properly.
* Tue Aug 11 2009 matejcik@suse.cz
- build as noarch on newer distros
* Wed Aug  5 2009 matejcik@suse.cz
- update to 1.2.12
  * minor bugfixes
  * support for --disable-depchecks
- using --disable-depchecks instead of pygtk patch
* Wed Feb 11 2009 ro@suse.de
- use sr@latin instead of sr@Latn
* Fri Mar 14 2008 matejcik@suse.cz
- update to 1.2.11
  * mainly bugfix release
  * updated translations
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Thu Jul 26 2007 jmatejek@suse.cz
- update to 1.2.10
  * better proxy support
  * improved translations
* Mon Apr 30 2007 ro@suse.de
- do not package mimeinfo.cache
* Fri Feb  2 2007 ro@suse.de
- remove scrollkeeper calls from post-scripts
* Fri Feb  2 2007 ro@suse.de
- move to /usr
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gnome-devel instead of python-gnome
* Fri Jul 14 2006 ke@suse.de
- Update to 1.2.9:
  * Toolbar search widget (Frédéric)
  * Improved latex aux file parsing (Frédéric)
  * Fixed bugs related to unicode search queries and bibtex keys (Frédéric)
  * Updated translations (Gnome I18n team)
* Thu Mar 30 2006 ke@suse.de
- Require python-bibtex version >= 1.2.2 and python-gtk version >=
  2.4.0; reported by Nils Becker [# 149594].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 17 2005 ke@suse.de
- Update  to 1.2.7.
- Disable python-gtk check.
* Mon Nov 29 2004 ke@suse.de
- Update to version 1.2.5:
  * Fix use of translations in the interface.
  * Fix argument handling in pybliographic.
  * Use the new Gtk File selector.
  * Fixes to the Ovid parser.
  * Fixes and improvements to the synthetic fields.
  * Fix search of accented words.
* Fri Nov 26 2004 ke@suse.de
- Also require python-xml at runtime; reported by Dieter Stark [#48557].
* Tue Nov 16 2004 ke@suse.de
- Fix .desktop file.
* Tue Oct 19 2004 ke@suse.de
- Rename 'no' locale directory to 'nb' [#27748].
* Tue Jul 20 2004 ke@suse.de
- Update to version 1.2.4:
  * Fix in the ISI and Ovid parsers.
  * Add new tool: pybtext.
  * Fix native editing of a new entry.
  * Improve documentation and translations.
  * Fix history in Medline queries.
  * Add support for annotations.
  * Fix issue with empty crossrefs.
* Mon Jun  7 2004 ke@suse.de
- Update to version 1.2.3:
  * Update translations.
  * Improve documentation.
  * Fix saving the sort order.
  * Configuration of the text widget to use for editing.
  * Configurable BibTeX date format.
  * Editing Crossrefs does not loose info anymore.
- Register .desktop file.
* Mon May 24 2004 ke@suse.de
- Also require python-bibtex; reported by Eva Brucherseifer [#41019].
* Wed Mar 17 2004 sbrabec@suse.cz
- Fixed scrollkeeper calling conventions (#36215).
* Tue Mar 16 2004 mcihar@suse.cz
- gconf is now on place where expected, so patch for it is not needed
* Fri Jan  9 2004 ke@suse.de
- Update to 1.2.2:
  * Update english documentation in Gnome format.
  * Additional shortcuts.
  * Update translations.
  * Medline queries return URLs to the paper.
  * Various bug fixes.
* Thu Nov 20 2003 ke@suse.de
- Update to 1.2.1:
  * Update translations (fr, it, nl, pt, sr).
  * Localization of the GUI.
  * Clickable URLs.
  * Various bug fixes (Configuration dialogs, crash on document history,
    etc.).
- Add python-orbit to Requires.
* Wed Oct 22 2003 mcihar@suse.cz
- updated to 1.1.93 (Gtk/Gnome 2 version)
- no root for build
- spec file cleanup
* Thu Aug 28 2003 mcihar@suse.cz
- explicitely require pygtk 1.2
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 27 2003 mcihar@suse.cz
- DEFS won't be defined anymore in pythons Makefile.pre.in so we
  have to define it in spec file (see python's patch #736417)
* Tue May  6 2003 mcihar@suse.cz
- fixed all broken paths to python binary from previous change
- fixed build with current python-gtk
* Thu Apr 10 2003 mcihar@suse.cz
- now uses build root
- corrected configure.in to use system aclocal macros
* Mon Mar 10 2003 sf@suse.de
- fixes for lib64
* Wed Jan 22 2003 ro@suse.de
- replaced gnome-python by python-gnome in Requires
* Wed Nov 27 2002 ro@suse.de
- replace gnome-python by python-gnome in neededforbuild
* Thu Oct 31 2002 ke@suse.de
- Update to version 1.0.11; from NEWS:
  * Improve Medline Search engine
  * Add incremental search capability
  * Small UI improvements
  * Small fixes in the BibTeX and ISI format
- pybliographer-configure.diff: Disable recode check; recode is fixed by
  now [# 11503].
- Remove obsolete medline patch.
* Fri Feb 15 2002 ke@suse.de
- Fix Requires: entry to make it more obvious which package the user is
  considered to install: s/python-gnome/gnome-python/ [# 13273].
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Dec 17 2001 ke@suse.de
- Apply pybliographer-medline.patch provided by Frederic Gobry to allow
  save in Medline format.
* Mon Dec 10 2001 ke@suse.de
- Update to version 1.0.10:
  - Add direct Medline Query Interface.
  - Add formatting style for APA (4th edition).
  - Miscellanous bug fixes (pybliographer-shared-libs.diff is
    obsolete).
  - .spec file: Call suse_update_config.
* Mon Oct 15 2001 ke@suse.de
- Don't use BuildRoot.  Python compiles the installed .py files (->
  .pyc) puts the name of installation directory into the .pyc files;
  this fixes #11503 in part.
* Fri Jun 29 2001 ke@suse.de
- Update to version 1.0.9.
- Move patch link patch by schwab (2001-04-09) to file
  pybliographer-shared-libs.diff; drop the other patches.
* Mon Apr  9 2001 schwab@suse.de
- Fixed to not try to link non-pic objects in shared lib.
- Fix toplevel makefile to use $(Python) from configure.
* Wed Mar 14 2001 ro@suse.de
- added xf86 to neededforbuild
* Tue Mar 13 2001 ro@suse.de
- neededforbuild python-gnome to gnome-python
* Wed Feb 21 2001 ke@suse.de
- Update to version 1.0.8.
* Wed Feb 21 2001 ke@suse.de
- Add Provides: and Obsoletes: (fix).
* Wed Jan 10 2001 ke@suse.de
- Fix shell magic string to avoid wrong deps requirements (reported by
  Thorsten Kukuk).
* Mon Nov 27 2000 egger@suse.de
- Simplified specfile.
- Updated to 1.0.7.
- Fixed #neededforbuild.
- Added python-gtk and python-gnome to the requirements.
* Thu Nov 23 2000 ke@suse.de
- Fix neededforbuid: python-gnome and python-gtk.
* Wed Nov 15 2000 ke@suse.de
- Update to version 1.0.6
- Add recode-devel t0 neededforbuild.
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Mon Oct 30 2000 kukuk@suse.de
- Add python-devel to neededforbuild
* Thu Oct 12 2000 ke@suse.de
- update to version 1.0.5.
- add URL tag.
* Mon Aug 14 2000 ke@suse.de
- update to version 1.0.4.
* Tue Jun  6 2000 ke@suse.de
- update to version 1.0.1.
* Thu May 18 2000 ke@suse.de
- update to version 1.0.0.
- add %%defattr to the files list.
* Tue Apr 18 2000 ke@suse.de
- update to version 0.9.11.
* Thu Apr 13 2000 ke@suse.de
- initial package: version 0.9.9.
